#!/bin/sh
# SPDX-License-Identifier: GPL-3.0-or-later
service named restart
